SoftwareInstall

MetaboLabPy - Home

MetaboLabPy - Documentation

Software Installation

MetaboLabPy

Software Installation

Software Installation - Home

Software Installation

The easiest way to install MetaboLabPy is via using the Anaconda python distribution.

- Download the anaconda python distribution at https://www.anaconda.com/download and install the python distribution.
- Open an Anaconda3 Powershell prompt (click on the windows icon
  Anaconda3 (64-bit)
  Anaconda Powershell Prompt) or open a Terminal window on macOS (open a Finder window, type ⌘ + ⇧ + U, then select Terminal).
- Create a virtual environment for metabolabpy and install the required software packages:

- conda create —name metabolabpy -y
- conda activate metabolabpy
- conda install python==3.9.6 -y
- pip install metabolabpy
- pip install qtmetabolabpy
- pip install metabolabpytools
- pip install pygamma

- Start the MetaboLabPy GUI by typing: qtmetabolabpy

A tutorial video can be found below.